@@ -14,8 +14,7 @@
 #    under the License.
 
 import mock
-
-from neutron.common import constants as n_const
+from neutron_lib import constants as n_const
 
 from infoblox_client import objects as ib_objects
 
